<?php
/**
*
* @package phpBB Extension - Facebook&Twitter slider
* @copyright (c) 2019 Theriddler - https://peppersrusforum.nl
* @license http://opensource.org/licenses/gpl-2.0.php GNU General Public License v2
*
*/

namespace theriddler\facebooktwitterslider\event;

use Symfony\Component\EventDispatcher\EventSubscriberInterface;

class listener implements EventSubscriberInterface
{
	/** @var \phpbb\template\template */
	protected $template;

	/** @var \phpbb\config\config */
	protected $config;

	/**
	* Constructor
	*
	* @param \phpbb\template\template			$template
	* @param \phpbb\config\config				$config
	*/
	public function __construct(\phpbb\template\template $template, \phpbb\config\config $config)
	{
		$this->template = $template;
		$this->config = $config;
	}

	static public function getSubscribedEvents()
	{
		return array(
			'core.user_setup'	=> 'load_language_on_setup',
			'core.page_header'	=> 'add_page_header_facebook_twitter_slide',
		);
	}

	/**
	 * @param object $event The event object
	 */
	public function load_language_on_setup($event)
	{
		$lang_set_ext = $event['lang_set_ext'];
		$lang_set_ext[] = array(
			'ext_name' => 'theriddler/facebooktwitterslider',
			'lang_set' => 'facebooktwitterslider',
		);
		$event['lang_set_ext'] = $lang_set_ext;
	}

	public function add_page_header_facebook_twitter_slide($event)
	{
		$this->template->assign_vars(array(
			'FACEBOOKSLIDE_ENABLE'				=> $this->config['facebookslide_enable'] ? true : false,
			'FACEBOOKSLIDE_URL_FIELD'			=> (isset($this->config['facebookslide_url_field'])) ? $this->config['facebookslide_url_field'] : '',
			'FACEBOOKSLIDE_APPID_FIELD'			=> (isset($this->config['facebookslide_appid_field'])) ? $this->config['facebookslide_appid_field'] : '',
			'TWITTERSLIDE_ENABLE'				=> $this->config['twitterslide_enable'] ? true : false,
			'TWITTERSLIDE_NAME_FIELD'			=> (isset($this->config['twitterslide_name_field'])) ? $this->config['twitterslide_name_field'] : '',
		));
	}
}
